/**
 * @packageDocumentation
 * @module array
 */
import { MonoTypeOperatorFunction, ObservableInput } from 'rxjs';
import { PredicateFn } from '../types/array-compare';
/**
 * The `differenceWith` can be used with an [Observable](https://rxjs-dev.firebaseapp.com/guide/observable) array of values
 * of T, passing in an array or Observable array of values to find the difference between the two. The returned array of
 * values only contains values from the source Observable
 *
 * An optional [[PredicateFn]] can be passed for more complex types, if none is passed a simple comparison (`===`)
 * will be used to determine the difference
 *
 * @typeParam T Type of item in the input array
 *
 * @param input Array of items use to get the difference between two arrays
 *
 * @example
 * ```ts
 * of(['a', 'b', 'c', 'd'])
 *  .pipe(differenceWith(['a', 'c']))
 *  .subscribe(console.log) // ['b', 'd']
 * ```
 *
 * @returns Array of values of difference between the source and input array
 * @category RxJS Array Difference
 */
declare function differenceWith<T>(input: T[]): MonoTypeOperatorFunction<T[]>;
/**
 * @param input Observable Array of items use to get the difference between two arrays
 *
 * @example
 * ```ts
 * of(['a', 'b', 'c', 'd'])
 *  .pipe(differenceWith(of(['a', 'c'])))
 *  .subscribe(console.log) // ['b', 'd']
 * ```
 *
 * @returns Array of values of difference between the source and input array
 * @category RxJS Array Difference
 */
declare function differenceWith<T>(input: ObservableInput<T[]>): MonoTypeOperatorFunction<T[]>;
/**
 * @param input Array of items use to get the difference between two arrays
 * @param predicate Function for comparison of arrays
 *
 * @example
 * ```ts
 * of(['a', 'b', 'c', 'd'])
 *  .pipe(differenceWith(['A', 'C'], (x, y) => x === y.toLowerCase()))
 *  .subscribe(console.log) // ['b', 'd']
 * ```
 *
 * @returns Array of values of difference between the source and input array
 * @category RxJS Array Difference
 */
declare function differenceWith<T>(input: T[], predicate: PredicateFn<T>): MonoTypeOperatorFunction<T[]>;
/**
 * @param input Observable Array of items use to get the difference between two arrays
 * @param predicate Function for comparison of arrays
 *
 * @example
 * ```ts
 * of(['a', 'b', 'c', 'd'])
 *  .pipe(differenceWith(of(['A', 'C']), (x, y) => x === y.toLowerCase()))
 *  .subscribe(console.log) // ['b', 'd']
 * ```
 *
 * @returns Array of values of difference between the source and input array
 * @category RxJS Array Difference
 */
declare function differenceWith<T>(input: ObservableInput<T[]>, predicate: PredicateFn<T>): MonoTypeOperatorFunction<T[]>;
export { differenceWith };
